@@ -16,10 +16,22 @@
   */
 #include <argv.h>
 
+ /*
+  * Global library.
+  */
+#include <mail_addr_form.h>
+
  /*
   * External interface.
   */
-extern ARGV *mail_addr_crunch(const char *, const char *);
+extern ARGV *mail_addr_crunch_opt(const char *, const char *, int, int);
+
+ /*
+  * The least-overhead form.
+  */
+#define mail_addr_crunch_ext_to_int(string, extension) \
+	mail_addr_crunch_opt((string), (extension), MA_FORM_EXTERNAL, \
+			MA_FORM_INTERNAL)
 
 /* LICENSE
 /* .ad
