@@ -441,17 +441,9 @@ TLS_APPL_STATE *tls_server_init(const TLS_SERVER_INIT_PROPS *props)
      * SSLv2), so we need to have the SSLv23 server here. If we want to limit
      * the protocol level, we can add an option to not use SSLv2/v3/TLSv1
      * later.
-     * 
-     * OpenSSL 1.1.0-dev deprecates SSLv23_server_method() in favour of
-     * TLS_client_method(), with the change in question signalled via a new
-     * TLS_ANY_VERSION macro.
      */
     ERR_clear_error();
-#if OPENSSL_VERSION_NUMBER >= 0x10100000L && defined(TLS_ANY_VERSION)
     server_ctx = SSL_CTX_new(TLS_server_method());
-#else
-    server_ctx = SSL_CTX_new(SSLv23_server_method());
-#endif
     if (server_ctx == 0) {
 	msg_warn("cannot allocate server SSL_CTX: disabling TLS support");
 	tls_print_errors();
@@ -510,23 +502,8 @@ TLS_APPL_STATE *tls_server_init(const TLS_SERVER_INIT_PROPS *props)
 	    ticketable = 0;
 	}
     }
-    if (ticketable) {
+    if (ticketable)
 	SSL_CTX_set_tlsext_ticket_key_cb(server_ctx, ticket_cb);
-
-	/*
-	 * OpenSSL 1.1.1 introduces support for TLS 1.3, which can issue more
-	 * than one ticket per handshake.  While this may be appropriate for
-	 * communication between browsers and webservers, it is not terribly
-	 * useful for MTAs, many of which other than Postfix don't do TLS
-	 * session caching at all, and Postfix has no mechanism for storing
-	 * multiple session tickets, if more than one sent, the second
-	 * clobbers the first.  OpenSSL 1.1.1 servers default to issuing two
-	 * tickets for non-resumption handshakes, we reduce this to one.  Our
-	 * ticket decryption callback already (since 2.11) asks OpenSSL to
-	 * avoid issuing new tickets when the presented ticket is re-usable.
-	 */
-	SSL_CTX_set_num_tickets(server_ctx, 1);
-    }
 #endif
     if (!ticketable)
 	off |= SSL_OP_NO_TICKET;
@@ -631,7 +608,7 @@ TLS_APPL_STATE *tls_server_init(const TLS_SERVER_INIT_PROPS *props)
      * Enable EECDH if available, errors are not fatal, we just keep going
      * with any remaining key-exchange algorithms.
      */
-    (void) tls_set_eecdh_curve(server_ctx, props->eecdh_grade);
+    tls_set_eecdh_curve(server_ctx, props->eecdh_grade);
 
     /*
      * If we want to check client certificates, we have to indicate it in
@@ -961,12 +938,14 @@ TLS_SESS_STATE *tls_server_post_accept(TLS_SESS_STATE *TLScontext)
 	tls_stream_start(TLScontext->stream, TLScontext);
 
     /*
-     * With the handshake done, extract TLS 1.3 signature metadata.
+     * All the key facts in a single log entry.
      */
-    tls_get_signature_params(TLScontext);
-
     if (TLScontext->log_mask & TLS_LOG_SUMMARY)
-	tls_log_summary(TLS_ROLE_SERVER, TLS_USAGE_NEW, TLScontext);
+	msg_info("%s TLS connection established from %s: %s with cipher %s "
+	      "(%d/%d bits)", !TLS_CERT_IS_PRESENT(TLScontext) ? "Anonymous"
+		 : TLS_CERT_IS_TRUSTED(TLScontext) ? "Trusted" : "Untrusted",
+	 TLScontext->namaddr, TLScontext->protocol, TLScontext->cipher_name,
+		 TLScontext->cipher_usebits, TLScontext->cipher_algbits);
 
     tls_int_seed();
 
